"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var identifiers_1 = require("../identifiers");
describe('identifiers', function () {
    describe('indyVdrAnonCredsRegistryIdentifierRegex', function () {
        test('matches against a legacy schema id, credential definition id and revocation registry id', function () {
            var did = '7Tqg6BwSSWapxgUDm9KKgg';
            var schemaId = 'BQ42WeE24jFHeyGg8x9XAz:2:Medical Bill:1.0';
            var credentialDefinitionId = 'N7baRMcyvPwWc8v85CtZ6e:3:CL:100669:SCH Employee ID';
            var revocationRegistryId = 'N7baRMcyvPwWc8v85CtZ6e:4:N7baRMcyvPwWc8v85CtZ6e:3:CL:100669:SCH Employee ID:CL_ACCUM:1-1024';
            var anotherId = 'some:id';
            // unqualified issuerId not in regex on purpose. See note in implementation.
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(did)).toEqual(false);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(schemaId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(credentialDefinitionId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(revocationRegistryId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(anotherId)).toEqual(false);
        });
        test('matches against a did indy did, schema id, credential definition id and revocation registry id', function () {
            var did = 'did:indy:local:7Tqg6BwSSWapxgUDm9KKgg';
            var schemaId = 'did:indy:local:BQ42WeE24jFHeyGg8x9XAz/anoncreds/v0/SCHEMA/Medical Bill/1.0';
            var credentialDefinitionId = 'did:indy:local:N7baRMcyvPwWc8v85CtZ6e/anoncreds/v0/CLAIM_DEF/100669/SCH Employee ID';
            var revocationRegistryId = 'did:indy:local:N7baRMcyvPwWc8v85CtZ6e/anoncreds/v0/REV_REG_DEF/100669/SCH Employee ID/1-1024';
            var anotherId = 'did:indy:local:N7baRMcyvPwWc8v85CtZ6e/anoncreds/v0/SOME_DEF';
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(did)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(schemaId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(credentialDefinitionId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(revocationRegistryId)).toEqual(true);
            expect(identifiers_1.indyVdrAnonCredsRegistryIdentifierRegex.test(anotherId)).toEqual(false);
        });
    });
    test('getDidIndySchemaId returns a valid schema id given a did, name, and version', function () {
        var namespace = 'sovrin:test';
        var did = '12345';
        var name = 'backbench';
        var version = '420';
        expect((0, identifiers_1.getDidIndySchemaId)(namespace, did, name, version)).toEqual('did:indy:sovrin:test:12345/anoncreds/v0/SCHEMA/backbench/420');
    });
    test('getDidIndyCredentialDefinitionId returns a valid credential definition id given a did, seqNo, and tag', function () {
        var namespace = 'sovrin:test';
        var did = '12345';
        var seqNo = 420;
        var tag = 'someTag';
        expect((0, identifiers_1.getDidIndyCredentialDefinitionId)(namespace, did, seqNo, tag)).toEqual('did:indy:sovrin:test:12345/anoncreds/v0/CLAIM_DEF/420/someTag');
    });
    test('getDidIndyRevocationRegistryId returns a valid credential definition id given a did, seqNo, and tag', function () {
        var namespace = 'sovrin:test';
        var did = '12345';
        var seqNo = 420;
        var credentialDefinitionTag = 'someTag';
        var tag = 'anotherTag';
        expect((0, identifiers_1.getDidIndyRevocationRegistryDefinitionId)(namespace, did, seqNo, credentialDefinitionTag, tag)).toEqual('did:indy:sovrin:test:12345/anoncreds/v0/REV_REG_DEF/420/someTag/anotherTag');
    });
});
