"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var transform_1 = require("../transform");
var createRevocationRegistryDefinition = function (maxCreds) { return ({
    value: {
        tailsHash: 'hash',
        maxCredNum: maxCreds,
        publicKeys: {
            accumKey: {
                z: 'key',
            },
        },
        tailsLocation: 'nowhere',
    },
    revocDefType: 'CL_ACCUM',
    tag: 'REV_TAG',
    issuerId: 'does:not:matter',
    credDefId: 'does:not:matter',
}); };
describe('transform', function () {
    var accum = 'does not matter';
    var revocationRegistryDefinitionId = 'does:not:matter';
    describe('indy vdr delta to anoncreds revocation status list', function () {
        test('issued and revoked are filled', function () {
            var delta = {
                accum: accum,
                issued: [0, 1, 2, 3, 4],
                revoked: [5, 6, 7, 8, 9],
                txnTime: 1,
            };
            var revocationRegistryDefinition = createRevocationRegistryDefinition(10);
            var statusList = (0, transform_1.anonCredsRevocationStatusListFromIndyVdr)(revocationRegistryDefinitionId, revocationRegistryDefinition, delta, true);
            expect(statusList.revocationList).toStrictEqual([0, 0, 0, 0, 0, 1, 1, 1, 1, 1]);
        });
        test('issued and revoked are empty (issuance by default)', function () {
            var delta = {
                accum: accum,
                issued: [],
                revoked: [],
                txnTime: 1,
            };
            var revocationRegistryDefinition = createRevocationRegistryDefinition(10);
            var statusList = (0, transform_1.anonCredsRevocationStatusListFromIndyVdr)(revocationRegistryDefinitionId, revocationRegistryDefinition, delta, true);
            expect(statusList.revocationList).toStrictEqual([0, 0, 0, 0, 0, 0, 0, 0, 0, 0]);
        });
        test('issued and revoked are empty (issuance on demand)', function () {
            var delta = {
                accum: accum,
                issued: [],
                revoked: [],
                txnTime: 1,
            };
            var revocationRegistryDefinition = createRevocationRegistryDefinition(10);
            var statusList = (0, transform_1.anonCredsRevocationStatusListFromIndyVdr)(revocationRegistryDefinitionId, revocationRegistryDefinition, delta, false);
            expect(statusList.revocationList).toStrictEqual([1, 1, 1, 1, 1, 1, 1, 1, 1, 1]);
        });
        test('issued index is too high', function () {
            var delta = {
                accum: accum,
                issued: [200],
                revoked: [5, 6, 7, 8, 9],
                txnTime: 1,
            };
            var revocationRegistryDefinition = createRevocationRegistryDefinition(10);
            expect(function () {
                return (0, transform_1.anonCredsRevocationStatusListFromIndyVdr)(revocationRegistryDefinitionId, revocationRegistryDefinition, delta, true);
            }).toThrowError();
        });
    });
    describe('create latest indy vdr delta from status list and previous delta', function () {
        test('delta and status list are equal', function () {
            var delta = {
                accum: accum,
                issued: [0, 1, 2, 3, 4],
                revoked: [5, 6, 7, 8, 9],
                txnTime: 1,
            };
            var revocationStatusList = [0, 0, 0, 0, 0, 1, 1, 1, 1, 1];
            var _a = (0, transform_1.indyVdrCreateLatestRevocationDelta)(accum, revocationStatusList, delta), revoked = _a.revoked, issued = _a.issued;
            expect(revoked).toStrictEqual([]);
            expect(issued).toStrictEqual([]);
        });
        test('real world case', function () {
            var revocationStatusList = [
                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            ];
            var delta = {
                revoked: [],
                issued: [
                    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
                    30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56,
                    57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
                    84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
                ],
                accum: '1 22D10308FEB1A73E5D231FBB231385A75AEFF05AFFC26C76CF6080B6831AC8F8 1 24D6BF977A437AD8BD4501070123CD096F680246D22A00B498FB1A660FAAD062 1 207D22D26EAD5941316BBDE33E19F41FE727507888ED750A2C49863AA2ACDCD1 1 243C032573EADB924D9C28BD21106AA2FB7994C85C80A2DAE89F5C011BCFA70C 2 095E45DDF417D05FB10933FFC63D474548B7FFFF7888802F07FFFFFF7D07A8A8 1 0000000000000000000000000000000000000000000000000000000000000000',
                txnTime: 1706887938,
            };
            var _a = (0, transform_1.indyVdrCreateLatestRevocationDelta)(accum, revocationStatusList, delta), revoked = _a.revoked, issued = _a.issued;
            expect(issued).toStrictEqual([]);
            expect(revoked).toStrictEqual([10]);
        });
        test('no previous delta', function () {
            var revocationStatusList = [0, 0, 0, 0, 0, 1, 1, 1, 1, 1];
            var _a = (0, transform_1.indyVdrCreateLatestRevocationDelta)(accum, revocationStatusList, undefined), revoked = _a.revoked, issued = _a.issued;
            expect(issued).toStrictEqual([0, 1, 2, 3, 4]);
            expect(revoked).toStrictEqual([5, 6, 7, 8, 9]);
        });
        test('status list and previous delta are out of sync', function () {
            var delta = {
                accum: accum,
                issued: [0],
                revoked: [5],
                txnTime: 1,
            };
            var revocationStatusList = [0, 0, 0, 0, 0, 1, 1, 1, 1, 1];
            var _a = (0, transform_1.indyVdrCreateLatestRevocationDelta)(accum, revocationStatusList, delta), revoked = _a.revoked, issued = _a.issued;
            expect(issued).toStrictEqual([1, 2, 3, 4]);
            expect(revoked).toStrictEqual([6, 7, 8, 9]);
        });
        test('previous delta index exceeds length of revocation status list', function () {
            var delta = {
                accum: accum,
                issued: [200],
                revoked: [5],
                txnTime: 1,
            };
            var revocationStatusList = [0, 0, 0, 0, 0, 1, 1, 1, 1, 1];
            expect(function () { return (0, transform_1.indyVdrCreateLatestRevocationDelta)(accum, revocationStatusList, delta); }).toThrowError();
        });
    });
});
