"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.anonCredsRevocationStatusListFromIndyVdr = anonCredsRevocationStatusListFromIndyVdr;
exports.indyVdrCreateLatestRevocationDelta = indyVdrCreateLatestRevocationDelta;
var core_1 = require("@credo-ts/core");
var RevocationState;
(function (RevocationState) {
    RevocationState[RevocationState["Active"] = 0] = "Active";
    RevocationState[RevocationState["Revoked"] = 1] = "Revoked";
})(RevocationState || (RevocationState = {}));
function anonCredsRevocationStatusListFromIndyVdr(revocationRegistryDefinitionId, revocationRegistryDefinition, delta, isIssuanceByDefault) {
    var _a, _b;
    // Check whether the highest delta index is supported in the `maxCredNum` field of the
    // revocation registry definition. This will likely also be checked on other levels as well
    // by the ledger or the indy-vdr library itself
    if (Math.max.apply(Math, __spreadArray(__spreadArray([], delta.issued, false), delta.revoked, false)) >= revocationRegistryDefinition.value.maxCredNum) {
        throw new core_1.CredoError("Highest delta index '".concat(Math.max.apply(Math, __spreadArray(__spreadArray([], delta.issued, false), delta.revoked, false)), "' is too large for the Revocation registry maxCredNum '").concat(revocationRegistryDefinition.value.maxCredNum, "' "));
    }
    // 0 means unrevoked, 1 means revoked
    var defaultState = isIssuanceByDefault ? RevocationState.Active : RevocationState.Revoked;
    // Fill with default value
    var revocationList = new Array(revocationRegistryDefinition.value.maxCredNum).fill(defaultState);
    // Set all `issuer` indexes to 0 (not revoked)
    for (var _i = 0, _c = (_a = delta.issued) !== null && _a !== void 0 ? _a : []; _i < _c.length; _i++) {
        var issued = _c[_i];
        revocationList[issued] = RevocationState.Active;
    }
    // Set all `revoked` indexes to 1 (revoked)
    for (var _d = 0, _e = (_b = delta.revoked) !== null && _b !== void 0 ? _b : []; _d < _e.length; _d++) {
        var revoked = _e[_d];
        revocationList[revoked] = RevocationState.Revoked;
    }
    return {
        issuerId: revocationRegistryDefinition.issuerId,
        currentAccumulator: delta.accum,
        revRegDefId: revocationRegistryDefinitionId,
        revocationList: revocationList,
        timestamp: delta.txnTime,
    };
}
/**
 *
 * Transforms the previous deltas and the full revocation status list into the latest delta
 *
 * ## Example
 *
 * input:
 *
 * revocationStatusList: [0, 1, 1, 1, 0, 0, 0, 1, 1, 0]
 * previousDelta:
 *   - issued: [1, 2, 5, 8, 9]
 *   - revoked: [0, 3, 4, 6, 7]
 *
 * output:
 *   - issued: [5, 9]
 *   - revoked: [3, 7]
 *
 */
function indyVdrCreateLatestRevocationDelta(currentAccumulator, revocationStatusList, previousDelta) {
    if (previousDelta && Math.max.apply(Math, __spreadArray(__spreadArray([], previousDelta.issued, false), previousDelta.revoked, false)) > revocationStatusList.length - 1) {
        throw new core_1.CredoError("Indy Vdr delta contains an index '".concat(Math.max.apply(Math, __spreadArray(__spreadArray([], previousDelta.revoked, false), previousDelta.issued, false)), "' that exceeds the length of the revocation status list '").concat(revocationStatusList.length, "'"));
    }
    var issued = [];
    var revoked = [];
    if (previousDelta) {
        revocationStatusList.forEach(function (revocationStatus, idx) {
            // Check whether the revocationStatusList entry is not included in the previous delta issued indices
            if (revocationStatus === RevocationState.Active && !previousDelta.issued.includes(idx)) {
                issued.push(idx);
            }
            // Check whether the revocationStatusList entry is not included in the previous delta revoked indices
            if (revocationStatus === RevocationState.Revoked && !previousDelta.revoked.includes(idx)) {
                revoked.push(idx);
            }
        });
    }
    else {
        // No delta is provided, initial state, so the entire revocation status list is converted to two list of indices
        revocationStatusList.forEach(function (revocationStatus, idx) {
            if (revocationStatus === RevocationState.Active)
                issued.push(idx);
            if (revocationStatus === RevocationState.Revoked)
                revoked.push(idx);
        });
    }
    return {
        issued: issued,
        revoked: revoked,
        accum: currentAccumulator,
        prevAccum: previousDelta === null || previousDelta === void 0 ? void 0 : previousDelta.accum,
    };
}
