"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
    return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndyVdrSovDidResolver = void 0;
var indy_vdr_shared_1 = require("@hyperledger/indy-vdr-shared");
var error_1 = require("../error");
var IndyVdrPoolService_1 = require("../pool/IndyVdrPoolService");
var didSovUtil_1 = require("./didSovUtil");
var IndyVdrSovDidResolver = /** @class */ (function () {
    function IndyVdrSovDidResolver() {
        this.supportedMethods = ['sov'];
        this.allowsCaching = true;
    }
    IndyVdrSovDidResolver.prototype.resolve = function (agentContext, did, parsed) {
        return __awaiter(this, void 0, void 0, function () {
            var didDocumentMetadata, indyVdrPoolService, pool, nym, endpoints, keyAgreementId, builder, error_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        didDocumentMetadata = {};
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 5, , 6]);
                        indyVdrPoolService = agentContext.dependencyManager.resolve(IndyVdrPoolService_1.IndyVdrPoolService);
                        return [4 /*yield*/, indyVdrPoolService.getPoolForDid(agentContext, parsed.id)];
                    case 2:
                        pool = (_a.sent()).pool;
                        return [4 /*yield*/, this.getPublicDid(pool, parsed.id)];
                    case 3:
                        nym = _a.sent();
                        return [4 /*yield*/, this.getEndpointsForDid(agentContext, pool, parsed.id)];
                    case 4:
                        endpoints = _a.sent();
                        keyAgreementId = "".concat(parsed.did, "#key-agreement-1");
                        builder = (0, didSovUtil_1.sovDidDocumentFromDid)(parsed.did, nym.verkey);
                        if (endpoints) {
                            (0, didSovUtil_1.addServicesFromEndpointsAttrib)(builder, parsed.did, endpoints, keyAgreementId);
                        }
                        return [2 /*return*/, {
                                didDocument: builder.build(),
                                didDocumentMetadata: didDocumentMetadata,
                                didResolutionMetadata: { contentType: 'application/did+ld+json' },
                            }];
                    case 5:
                        error_2 = _a.sent();
                        return [2 /*return*/, {
                                didDocument: null,
                                didDocumentMetadata: didDocumentMetadata,
                                didResolutionMetadata: {
                                    error: 'notFound',
                                    message: "resolver_error: Unable to resolve did '".concat(did, "': ").concat(error_2),
                                },
                            }];
                    case 6: return [2 /*return*/];
                }
            });
        });
    };
    IndyVdrSovDidResolver.prototype.getPublicDid = function (pool, unqualifiedDid) {
        return __awaiter(this, void 0, void 0, function () {
            var request, didResponse;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        request = new indy_vdr_shared_1.GetNymRequest({ dest: unqualifiedDid });
                        return [4 /*yield*/, pool.submitRequest(request)];
                    case 1:
                        didResponse = _a.sent();
                        if (!didResponse.result.data) {
                            throw new error_1.IndyVdrNotFoundError("DID ".concat(unqualifiedDid, " not found"));
                        }
                        return [2 /*return*/, JSON.parse(didResponse.result.data)];
                }
            });
        });
    };
    IndyVdrSovDidResolver.prototype.getEndpointsForDid = function (agentContext, pool, did) {
        return __awaiter(this, void 0, void 0, function () {
            var request, response, endpoints, error_3;
            var _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _b.trys.push([0, 2, , 3]);
                        agentContext.config.logger.debug("Get endpoints for did '".concat(did, "' from ledger '").concat(pool.indyNamespace, "'"));
                        request = new indy_vdr_shared_1.GetAttribRequest({ targetDid: did, raw: 'endpoint' });
                        agentContext.config.logger.debug("Submitting get endpoint ATTRIB request for did '".concat(did, "' to ledger '").concat(pool.indyNamespace, "'"));
                        return [4 /*yield*/, pool.submitRequest(request)];
                    case 1:
                        response = _b.sent();
                        if (!response.result.data) {
                            return [2 /*return*/, null];
                        }
                        endpoints = (_a = JSON.parse(response.result.data)) === null || _a === void 0 ? void 0 : _a.endpoint;
                        agentContext.config.logger.debug("Got endpoints '".concat(JSON.stringify(endpoints), "' for did '").concat(did, "' from ledger '").concat(pool.indyNamespace, "'"), {
                            response: response,
                            endpoints: endpoints,
                        });
                        return [2 /*return*/, endpoints !== null && endpoints !== void 0 ? endpoints : null];
                    case 2:
                        error_3 = _b.sent();
                        agentContext.config.logger.error("Error retrieving endpoints for did '".concat(did, "' from ledger '").concat(pool.indyNamespace, "'"), {
                            error: error_3,
                        });
                        throw new error_1.IndyVdrError(error_3);
                    case 3: return [2 /*return*/];
                }
            });
        });
    };
    return IndyVdrSovDidResolver;
}());
exports.IndyVdrSovDidResolver = IndyVdrSovDidResolver;
